# MFASweep

Python port of [MFASweeb](https://github.com/dafthack/MFASweep) by @dafthack

## Install

**Install from github**
```bash
python3 -m pip install git+https://github.com/CasperGN/MFASweep.py.git
```

**Install from pip**
```bash
python3 -m pip install MFASweep.py
```

## Usage

```bash
python3 -m mfasweep username domain.com
```
